@@ -394,7 +394,7 @@ class User(avatar_mixin(100, 'login'), DeactivableMixin, ModelSQL, ModelView):
             all_users += users
             args.extend((users, cls._convert_vals(values)))
 
-            if 'password' in values:
+            if values.keys() & {'active', 'password'}:
                 session_to_clear += users
                 users_to_clear += [u.login for u in users]
 
@@ -1025,12 +1025,16 @@ class Warning_(ModelSQL, ModelView):
         context = transaction.context
         if not user or context.get('_skip_warnings'):
             return False
+        key = (user, warning_name)
+        if key in transaction.check_warnings:
+            return False
         warnings = cls.search([
             ('user', '=', user),
             ('name', '=', warning_name),
             ])
         if not warnings:
             return True
+        transaction.check_warnings.add(key)
         cls.delete([x for x in warnings if not x.always])
         return False
 
